@@ -89,14 +89,17 @@ class JobBuilder():
     def resource_per_trial(self, value):
         resource = JobBuilder.get_resource_info()
         resource_per_trial = {}
+        num_trials = self.num_trials if self.num_trials != -1 else max(resource['gpu'], 1)
+        max_concurrent = min(num_trials, self.max_concurrent)
         for device in ['cpu', 'gpu']:
-            if resource[device] >= self.max_concurrent:
-                resource_per_trial[device] = int(resource[device]/self.max_concurrent)  
-            elif resource[device] > 0:
-                resource_per_trial[device] = resource[device]/self.max_concurrent
+            n_device = resource[device]
+            if n_device >= self.max_concurrent:
+                resource_per_trial[device] = int(n_device/max_concurrent)  
+            elif n_device > 0:
+                resource_per_trial[device] = n_device/max_concurrent
             else:
                 resource_per_trial[device] = 0
-        max_concurrent = self.max_concurrent
+                
         if isinstance(value, dict):
             for device in ['cpu', 'gpu']:
                 if device in value and value[device]:
