@@ -276,9 +276,8 @@ class ConfigurationBase(object):
             if key in config:
                 # check if the value type of the config is correct
                 value_type = config_format[key]['type']
-                
                 # if attribute type is dict, parse string input as dict
-                if (value_type == dict) or (isinstance(value_type, tuple) and ('dict' in value_type)):
+                if (value_type == dict) or (isinstance(value_type, tuple) and (dict in value_type)):
                     if isinstance(config[key], str):
                         try:
                             validated_config[key] = json.loads(config[key])
