@@ -197,12 +197,15 @@ def cd(newdir):
 
 def get_physical_devices(device_type='GPU'):
     import tensorflow as tf
-    physical_devices = tf.config.list_physical_devices('GPU')
+    physical_devices = tf.config.list_physical_devices(device_type)
     return physical_devices
 
 def get_n_gpu():
+    '''
     import torch
     return torch.cuda.device_count()
+    '''
+    return len(get_physical_devices(device_type='GPU'))
 
 def get_n_cpu():
     return multiprocessing.cpu_count()
